@@ -1,7 +1,11 @@
-def _use_self(funct):
+def _use_self_or_cls(funct):
     from inspect import signature, _empty
     s = signature(funct)
-    return "self" in s.parameters and s.parameters["self"].annotation is _empty
+    b = "self" in s.parameters and s.parameters["self"].annotation is _empty
+    if b:
+        return b
+    b = "cls" in s.parameters and s.parameters["cls"].annotation is _empty
+    return b
 
 
 def json_force_parameter_type_function(funct):
@@ -31,7 +35,7 @@ def json_force_parameter_type_function(funct):
 
 
 def json_force_parameter_type_method(funct):
-    def decorated(self, *args, **kwargs):
+    def decorated(self_or_cls, *args, **kwargs):
         from inspect import signature
         from .json_object import JsonObject, JsonList
         if args:
@@ -57,7 +61,7 @@ def json_force_parameter_type_method(funct):
 
 
 def json_force_parameter_type(funct):
-    if _use_self(funct):
+    if _use_self_or_cls(funct):
         return json_force_parameter_type_method(funct)
     else:
         return json_force_parameter_type_function(funct)
@@ -74,17 +78,17 @@ def json_parameters_function(funct):
 
 
 def json_parameters_method(funct):
-    def decorated(self, json_object):
+    def decorated(self_or_cls, json_object):
         from .json_object import JsonObject
         if not isinstance(json_object, JsonObject):
             raise TypeError("Parameter must be JsonObject instance")
         p = json_object.to_dict()
-        return funct(self, **p)
+        return funct(self_or_cls, **p)
     return decorated
 
 
 def json_parameters(funct):
-    if _use_self(funct):
+    if _use_self_or_cls(funct):
         return json_parameters_method(funct)
     else:
         return json_parameters_function(funct)
@@ -93,13 +97,13 @@ def json_parameters(funct):
 def json_parse(json_object_type=None):
     def decorator(funct):
         from .json_object import JsonObject
-        if _use_self(funct):
+        if _use_self_or_cls(funct):
             if json_object_type:
-                def decorated(self, json_string: str):
-                    return funct(self, json_object_type.parse(json_string))
+                def decorated(self_or_cls, json_string: str):
+                    return funct(self_or_cls, json_object_type.parse(json_string))
             else:
-                def decorated(self, json_string: str):
-                    return funct(self, JsonObject.load(json_string))
+                def decorated(self_or_cls, json_string: str):
+                    return funct(self_or_cls, JsonObject.load(json_string))
         else:
             if json_object_type:
                 def decorated(json_string: str):
@@ -108,7 +112,8 @@ def json_parse(json_object_type=None):
                 def decorated(json_string: str):
                     return funct(JsonObject.load(json_string))
         return decorated
-    if callable(json_object_type):
+    from .json_object import JsonObject
+    if not type(json_object_type) is type:
         funct = json_object_type
         json_object_type = None
         return decorator(funct)
